@@ -1,4 +1,4 @@
-from robot.api.parsing import ElseHeader, ElseIfHeader, End, If, IfHeader, KeywordCall, ModelTransformer, Token
+from robot.api.parsing import ElseHeader, ElseIfHeader, End, If, IfHeader, KeywordCall, Token
 
 from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
 from robotidy.transformers import Transformer
@@ -81,8 +81,6 @@ class ReplaceRunKeywordIf(Transformer):
             Keyword2
         END
     ```
-
-    Supports global formatting params: ``--spacecount``, ``--separator``, ``--startline`` and ``--endline``.
     """
 
     def __init__(self):
